@@ -8,7 +8,7 @@ package Tickit::Event;
 use strict;
 use warnings;
 
-our $VERSION = '0.70_001';
+our $VERSION = '0.58';
 
 use Carp;
 
@@ -18,10 +18,13 @@ C<Tickit::Event> - event information structures
 
 =head1 DESCRIPTION
 
-When event handlers bound to L<Tickit::Term> or L<Tickit::Window> instances
-are invoked they receive an object instance to contain information about the
-event. Details of the event can be accessed as via accessor methods on these
-instances.
+When event handlers bound to L<Tickit::Term> instances are invoked they
+receive an object instance to contain information about the event. Details of
+the event can be accessed as via accessor methods on these instances.
+
+For back-compatibility, each event type also provides a hash reference
+overload method that yields a hash containing keys named after the accessors.
+This code will be removed in a later version as per deprecation policy.
 
 =head1 ACCESSORS
 
@@ -39,56 +42,19 @@ modifiers is set.
 
 =cut
 
-sub mod_is_alt   { shift->mod & Tickit::MOD_ALT }
-sub mod_is_ctrl  { shift->mod & Tickit::MOD_CTRL }
-sub mod_is_shift { shift->mod & Tickit::MOD_SHIFT }
-
-package
-   Tickit::Event::Expose;
-our @ISA = qw( Tickit::Event );
-
-=head1 Tickit::Event::Expose
-
-=head2 rb
-
-The L<Tickit::RenderBuffer> instance containing the buffer for this redraw
-cycle.
-
-=head2 rect
-
-A L<Tickit::Rect> instance containing the region of the window that needs
-repainting.
-
-=cut
-
-package
-   Tickit::Event::Focus;
-our @ISA = qw( Tickit::Event );
-
-=head1 Tickit::Event::Focus
-
-=head2 type
-
-This accessor has two forms of operation.
-
-The new behaviour is that it returns a dualvar giving the focus event type as
-an integer or a string event name (C<in> or C<out>). This behaviour is
-selected if the method is invoked with any true value as an argument.
-
-The legacy behaviour is that it returns a simple boolean giving the focus
-direction; C<1> for in, C<0> for out. This legacy behaviour will be removed in
-a later version.
-
-=head2 win
-
-The child L<Tickit::Window> instance for child-focus notify events.
-
-=cut
+sub mod_is_alt   { shift->mod & Tickit::Term::MOD_ALT }
+sub mod_is_ctrl  { shift->mod & Tickit::Term::MOD_CTRL }
+sub mod_is_shift { shift->mod & Tickit::Term::MOD_SHIFT }
 
 package
    Tickit::Event::Key;
 our @ISA = qw( Tickit::Event );
 
+use overload '%{}' => sub {
+   my $self = shift;
+   return +{ map { $_ => $self->$_ } qw( type str mod ) };
+};
+
 =head1 Tickit::Event::Key
 
 =head2 type
@@ -109,6 +75,11 @@ package
    Tickit::Event::Mouse;
 our @ISA = qw( Tickit::Event );
 
+use overload '%{}' => sub {
+   my $self = shift;
+   return +{ map { $_ => $self->$_ } qw( type button line col mod ) };
+};
+
 =head1 Tickit::Event::Mouse
 
 =head2 type
@@ -136,6 +107,11 @@ package
    Tickit::Event::Resize;
 our @ISA = qw( Tickit::Event );
 
+use overload '%{}' => sub {
+   my $self = shift;
+   return +{ map { $_ => $self->$_ } qw( lines cols ) };
+};
+
 =head1 Tickit::Event::Resize
 
 =head2 lines
