@@ -8,7 +8,7 @@ package Tickit::Pen;
 use strict;
 use warnings;
 
-our $VERSION = '0.57';
+our $VERSION = '0.58';
 
 use Carp;
 
@@ -312,16 +312,6 @@ sub default_from
    return $self;
 }
 
-sub add_on_changed
-{
-   croak "\$pen->add_on_changed has been removed";
-}
-
-sub remove_on_changed
-{
-   croak "\$pen->remove_on_changed has been removed";
-}
-
 sub sprintf
 {
    my $self = shift;
@@ -344,14 +334,14 @@ use overload '==' => sub { refaddr($_[0]) == refaddr($_[1]) };
 package Tickit::Pen::Immutable;
 use base qw( Tickit::Pen );
 use constant mutable => 0;
-our $VERSION = '0.57';
+our $VERSION = '0.58';
 
 sub as_immutable { return $_[0] }
 
 package Tickit::Pen::Mutable;
 use base qw( Tickit::Pen );
 use constant mutable => 1;
-our $VERSION = '0.57';
+our $VERSION = '0.58';
 
 # Adds further methods in XS
 
