@@ -8,7 +8,7 @@ package Tickit::Term;
 use strict;
 use warnings;
 
-our $VERSION = '0.57';
+our $VERSION = '0.58';
 
 use Carp;
 
@@ -37,9 +37,9 @@ C<Tickit::Term> - terminal formatting abstraction
 
 =head1 DESCRIPTION
 
-Provides terminal control primatives for L<Tickit>; a number of methods that
+Provides terminal control primitives for L<Tickit>; a number of methods that
 control the terminal by writing control strings. This object itself performs
-no acutal IO work; it writes bytes to a delegated object given to the
+no actual IO work; it writes bytes to a delegated object given to the
 constructor called the writer.
 
 This object is not normally constructed directly by the containing
@@ -133,6 +133,12 @@ readable filehandle on the same file number.
 
 =cut
 
+sub get_input_handle
+{
+   my $self = shift;
+   return IO::Handle->new_from_fd( $self->get_input_fd, "r" );
+}
+
 =head2 get_output_handle
 
    $fh = $term->get_output_handle
@@ -147,6 +153,12 @@ writable filehandle on the same file number.
 
 =cut
 
+sub get_output_handle
+{
+   my $self = shift;
+   return IO::Handle->new_from_fd( $self->get_output_fd, "w" );
+}
+
 =head2 set_output_buffer
 
    $term->set_output_buffer( $len )
@@ -182,32 +194,10 @@ the given terminal, the event name, a C<HASH> reference containing event
 arguments, and the C<$data> value. It returns an ID value that may be used to
 remove the handler by calling C<unbind_event_id>.
 
- $ret = $code->( $term, $ev, $args, $data )
+ $ret = $code->( $term, $ev, $info, $data )
 
-The C<$args> hash will contain keys depending on the event type:
-
-=over 8
-
-=item key
-
-The hash will contain C<type> (a dualvar giving the key event type as an
-integer or string event name, C<text> or C<key>), C<str> (a string containing
-the key event string), and C<mod> (an integer bitmask indicating the modifier
-state).
-
-=item mouse
-
-The hash will contain C<type> (a dualvar giving the mouse event type as an
-integer or string event name, C<press>, C<drag>, C<release> or C<wheel>),
-C<button> (an integer for non-wheel events, or a dualvar for wheel events
-giving the wheel direction as C<up> or C<down>), C<line> and C<col> as
-integers, and C<mod> (an integer bitmask indicating the modifier state).
-
-=item resize
-
-The hash will contain C<lines> and C<cols> as integers.
-
-=back
+C<$info> will be an instance of some class of L<Tickit::Event> depending on
+the event type.
 
 =head2 bind_event (with flags)
 
@@ -247,44 +237,17 @@ sub bind_event
 
 sub set_on_resize
 {
-   my $self = shift;
-   my ( $code ) = @_;
-
-   carp "\$term->set_on_resize is deprecated; use ->bind_event";
-
-   $self->unbind_event_id( delete $self->_event_ids->{resize} ) if exists $self->_event_ids->{resize};
-   $self->_event_ids->{resize} = $self->bind_event( resize => sub {
-      my ( undef, $ev, $args ) = @_;
-      $code->( $self, $args->{lines}, $args->{cols} );
-   } );
+   croak "\$term->set_on_resize is deprecated; use ->bind_event";
 }
 
 sub set_on_key
 {
-   my $self = shift;
-   my ( $code ) = @_;
-
-   carp "\$term->set_on_key is deprecated; use ->bind_event";
-
-   $self->unbind_event_id( delete $self->_event_ids->{key} ) if exists $self->_event_ids->{key};
-   $self->_event_ids->{key} = $self->bind_event( key => sub {
-      my ( undef, $ev, $args ) = @_;
-      $code->( $self, $args->{type}, $args->{str} );
-   } );
+   croak "\$term->set_on_key is deprecated; use ->bind_event";
 }
 
 sub set_on_mouse
 {
-   my $self = shift;
-   my ( $code ) = @_;
-
-   carp "\$term->set_on_mouse is deprecated; use ->bind_event";
-
-   $self->unbind_event_id( delete $self->_event_ids->{mouse} ) if exists $self->_event_ids->{mouse};
-   $self->_event_ids->{mouse} = $self->bind_event( mouse => sub {
-      my ( undef, $ev, $args ) = @_;
-      $code->( $self, $args->{type}, $args->{button}, $args->{line}, $args->{col} );
-   } );
+   croak "\$term->set_on_mouse is deprecated; use ->bind_event";
 }
 
 =head2 refresh_size
