@@ -47,7 +47,7 @@ struct TickitTerm {
   TermKey              *termkey;
   struct timeval        input_timeout_at; /* absolute time */
 
-  const char *termtype;
+  char *termtype;
   TickitMaybeBool is_utf8;
 
   char *outbuffer;
@@ -195,9 +195,6 @@ TickitTerm *tickit_term_open_stdio(void)
 
 void tickit_term_free(TickitTerm *tt)
 {
-  tickit_hooklist_unbind_and_destroy(tt->hooks, tt);
-  tickit_pen_unref(tt->pen);
-
   if(tt->observe_winch)
     tickit_term_observe_sigwinch(tt, false);
 
@@ -210,6 +207,12 @@ void tickit_term_free(TickitTerm *tt)
 
   tickit_term_flush(tt);
 
+  if(tt->outfunc)
+    (*tt->outfunc)(tt, NULL, 0, tt->outfunc_user);
+
+  tickit_hooklist_unbind_and_destroy(tt->hooks, tt);
+  tickit_pen_unref(tt->pen);
+
   if(tt->termkey)
     termkey_destroy(tt->termkey);
 
@@ -219,6 +222,9 @@ void tickit_term_free(TickitTerm *tt)
   if(tt->tmpbuffer)
     free(tt->tmpbuffer);
 
+  if(tt->termtype)
+    free(tt->termtype);
+
   free(tt);
 }
 
@@ -360,6 +366,9 @@ int tickit_term_get_output_fd(const TickitTerm *tt)
 
 void tickit_term_set_output_func(TickitTerm *tt, TickitTermOutputFunc *fn, void *user)
 {
+  if(tt->outfunc)
+    (*tt->outfunc)(tt, NULL, 0, tt->outfunc_user);
+
   tt->outfunc      = fn;
   tt->outfunc_user = user;
 
